@@ -9,15 +9,24 @@
 #' )
 #' @export
 i14y_get_content_information <- function(
-    identifier = NULL
+  identifier = NULL
 ) {
   check_not_null(identifier)
   check_string(identifier)
-  check_internet()
+  if (!curl::has_internet()) {
+    message("No internet connection")
+    return(NULL)
+  }
 
   req <- httr2::request("https://www.i14y.admin.ch")
-  req <- httr2::req_user_agent(req, "I14Y R package (https://github.com/lgnbhl/I14Y)")
-  req <- httr2::req_url_path_append(req, paste0("/api/ContentConfigurations/", identifier))
+  req <- httr2::req_user_agent(
+    req,
+    "I14Y R package (https://github.com/lgnbhl/I14Y)"
+  )
+  req <- httr2::req_url_path_append(
+    req,
+    paste0("/api/ContentConfigurations/", identifier)
+  )
   req <- httr2::req_retry(req, max_tries = 2)
   req <- httr2::req_perform(req)
   resp <- httr2::resp_body_json(req, simplifyVector = TRUE, flatten = TRUE)
